@@ -655,7 +655,7 @@ paramInfo$empirical$optimalShape =
 		
 	if(adjustEdges!=FALSE){
 		if(is.logical(adjustEdges)) {
-			adjustEdges='theo'
+			adjustEdges='optimalShape'
 		}
 		
 		distVecFull =  expand.grid(x=seq(1, Nx),
@@ -722,148 +722,3 @@ paramInfo$empirical$optimalShape =
 	return(theNNmat)
 }
 	
-NNmat = function(N,Ny=N,nearest=3) {
-		UseMethod("NNmat")	
-}
-	
-NNmat.Raster = function(N,Ny=N,nearest=3) {
-	res = NNmat(ncol(N),nrow(N),nearest)
-	
-	attributes(res)$raster= raster(N)
-	
-	res
-}	
-
-NNmat.default = function(N, Ny=N,nearest=3) {
-
-	Nx = N
-	Ncol = Nx
-	Nrow=Ny
-	Ncell = Nrow*Ncol
-	
-#	images.bresult = Matrix(data=0,nrow=Ncell, ncol=Ncell, sparse=T)
-	Scell = 1:Ncell
-	result = sparseMatrix(Scell, Scell, x=rep(1, Ncell),symmetric=TRUE)
-#	diag(result) = 1
-	
-
-	
-	# interior points
-	oneN = c(1, -1, Ncol, -Ncol) # first neighbours up down right left
-	if(nearest>=2) {
-		twoN = c(Ncol-1, Ncol+1, -Ncol-1, -Ncol+1)  # first neighbours diagonal
-		threeN = c(2, -2, 2*Ncol, -2*Ncol) # second neighbours up down right left
-	} else {
-		twoN = threeN = c()
-	}
-	
-	fourN = c(3, -3, 3i, -3i) # square
-	fiveseq = c(-1, -2, 1, 2) # diagonals
-	fiveN = c(outer(fiveseq, fiveseq*1i, FUN="+"))
-	fiveN = fiveN[abs(Re(fiveN) )!= abs(Im(fiveN))]
-	if(nearest>=3) {
-		fourNindex = Re(fourN) + Im(fourN)*Ncol
-		fiveNindex = Re(fiveN) + Im(fiveN)*Ncol
-	} else {
-		fourNindex = fiveNindex = c()
-	}
-	
-	if(all(c(Nrow,Ncol) >= 7)) {
-		Scol = seq(4, Ncol-3)
-		
-		NeighbourIndexSeq = c(oneN, twoN, threeN, fourNindex,fiveNindex)
-		NeighbourSeq = c(rep(2,length(oneN)), 
-				rep(3 ,length(twoN)), 
-				rep(4,length(threeN)), 
-				rep(6 ,length(fourNindex)),
-				rep(5 ,length(fiveNindex))
-		)
-		
-
-	for(Drow in seq(4,Nrow-3)) {
-		Prow =  (Drow-1)*Ncol
-		for(Dcol in Scol){
- 
-			Dcell =  Prow + Dcol
-			
-			result[Dcell + NeighbourIndexSeq,Dcell] = NeighbourSeq
-		}
-	}
-	}	
-
-	# the borders
-	
-	theNc = cbind(oneN = c(1, -1, 1i, -1i), # first neighbours up down right left
-			
-	twoN = c(1-1i, -1+1i, -1i-1, 1i+1),  # first neighbours diagonal
-	threeN = c(2, -2, 2i, -2i), # second neighbours up down right left
-	fourN=fourN)	
-	theNcVec = c(theNc[,"oneN"],
-			theNc[,"twoN"],
-			theNc[,"threeN"],
-			theNc[,"fourN"],
-			fiveN)
-	theNcEntries = c(
-			rep(2, dim(theNc)[1]),
-			rep(3, dim(theNc)[1]),
-			rep(4, dim(theNc)[1]),
-			rep(6, dim(theNc)[1]),
-			rep(5, length(fiveN))			
-			)
-	if(nearest==1) {
-		whichTwo = theNcEntries==2
-		theNcVec = theNcVec[whichTwo]
-		theNcEntries = theNcEntries[whichTwo]
-	}	
-	if(nearest==2) {
-		whichTwo = theNcEntries<=4
-		theNcVec = theNcVec[whichTwo]
-		theNcEntries = theNcEntries[whichTwo]
-	}	
-	
-
-			
-	Scol = unique(c(1,2,3,Ncol-2,Ncol-1, Ncol))
-	for(Drow in 1:Nrow) {
-		Prow =  (Drow-1)*Ncol
-		for(Dcol in Scol){
-			Dcell = Prow + Dcol
-			Ccell = Drow + 1i*Dcol
-			Nhere = theNcVec + Ccell
-			
-			outsideBox = Re(Nhere) < 1 | Re(Nhere)>Nrow | 
-					Im(Nhere) < 1 | Im(Nhere) > Ncol
-			inBox = !outsideBox
-			
-			NhereIndex = (Re(Nhere) -1)*Ncol + Im(Nhere)
-			
-			result[NhereIndex[inBox],Dcell ] = theNcEntries[inBox]
-		}			
-	}
-	Srow = unique(c(1,2,3,Nrow-2,Nrow-1, Nrow))
-	Scol = seq(4, Ncol-3)
-	for(Drow in Srow) {
-		Prow =  (Drow-1)*Ncol
-		for(Dcol in Scol){
-			Dcell = Prow + Dcol
-			Ccell = Drow + 1i*Dcol
-			Nhere = theNcVec + Ccell
-			
-			outsideBox = Re(Nhere) < 1 | Re(Nhere)>Nrow | 
-					Im(Nhere) < 1 | Im(Nhere) > Ncol
-			inBox = !outsideBox
-			
-			NhereIndex = (Re(Nhere) -1)*Ncol + Im(Nhere)
-			
-			result[NhereIndex[inBox],Dcell ] = theNcEntries[inBox]
-		}			
-	}
-	
-	result = forceSymmetric(result)
-	
-	attributes(result)$Nx = Nx
-	attributes(result)$Ny = Ny
-
-	
-	return(result)
-}
\ No newline at end of file
